Class: Torque::RecordPathnameSettings

Inherits:
Object
  • Object
show all
Defined in:
lib/torque/record_pathname_settings.rb

Overview

Generates the pathname to use for the record file of the release notes

Instance Method Summary collapse

Constructor Details

#initialize(output_dir, project, custom_date_range, fs) ⇒ RecordPathnameSettings

Returns a new instance of RecordPathnameSettings.

Parameters:

  • output_dir

    The path to the release notes output directory

  • project

    The project id

  • custom_date_range

    True if a custom date range is being used, else false

  • fs

    An instance of the FileSystem class



14
15
16
17
18
19
# File 'lib/torque/record_pathname_settings.rb', line 14

def initialize(output_dir, project, custom_date_range, fs)
  @output_dir = output_dir
  @project = project
  @custom = custom_date_range
  @fs = fs
end

Instance Method Details

#get_pathObject

Returns the path to the record file, generating one if it does not exist



23
24
25
26
# File 'lib/torque/record_pathname_settings.rb', line 23

def get_path
  generate_record_path if !@path
  @path
end