Class: Torque::Version
- Inherits:
-
Object
- Object
- Torque::Version
- Defined in:
- lib/torque/version.rb
Constant Summary collapse
- MAJOR =
- MINOR =
- PATCH =
- STRING =
[MAJOR, MINOR, PATCH].compact.join('.')
Class Method Summary collapse
-
.string ⇒ Object
The string representing the current version of Torque (eg “1.9.2”).
Class Method Details
.string ⇒ Object
The string representing the current version of Torque (eg “1.9.2”)
19 20 21 |
# File 'lib/torque/version.rb', line 19 def self.string STRING end |